@@ -111,25 +111,27 @@ class Connections(WMLResource):
             header_param['IBM-WDP-Impersonate'] = str({'iam_id': str(self._client._iam_id)})
 
         if connection_id:
-            response = requests.get(
-                self._client.service_instance._href_definitions.get_connection_by_id_href(connection_id),
-                params=self._client._params(),
-                headers=header_param)
+            with self.requests_retry_session() as sess:
+                response = sess.get(
+                    self._client.service_instance._href_definitions.get_connection_by_id_href(connection_id),
+                    params=self._client._params(),
+                    headers=header_param)
 
-            if response.status_code == 200:
-                return self._get_required_element_from_response(
-                    self._handle_response(200, u'get connection details', response))
-            else:
-                return self._handle_response(200, u'get connection details', response)
+                if response.status_code == 200:
+                    return self._get_required_element_from_response(
+                        self._handle_response(200, u'get connection details', response))
+                else:
+                    return self._handle_response(200, u'get connection details', response)
         else:
-            response = requests.get(self._client.service_instance._href_definitions.get_connections_href(),
+            with self.requests_retry_session() as sess:
+                response = sess.get(self._client.service_instance._href_definitions.get_connections_href(),
                                     params=self._client._params(),
                                     headers=header_param)
 
-            if response.status_code == 200:
-                return {'resources': [self._get_required_element_from_response(x) for x in response.json()['resources']]}
-            else:
-                return self._handle_response(200, u'get connection details', response)
+                if response.status_code == 200:
+                    return {'resources': [self._get_required_element_from_response(x) for x in response.json()['resources']]}
+                else:
+                    return self._handle_response(200, u'get connection details', response)
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def create(self, meta_props):
@@ -540,7 +542,7 @@ class Connections(WMLResource):
         return unquote(response.headers['Location'])
 
     @staticmethod
-    def requests_retry_session(retries=3, backoff_factor=0.3, status_forcelist=(500, 502, 503, 504), session=None):
+    def requests_retry_session(retries=3, backoff_factor=0.3, status_forcelist=(500, 502, 503, 504, 521, 524), session=None):
         from requests.adapters import HTTPAdapter
         from requests.packages.urllib3.util.retry import Retry
 
