@@ -1003,13 +1003,13 @@ class Deployments(WMLResource):
                     **returns**: metadata of updated deployment\n
                     **return type**: dict\n
 
-                **Example**
+                **Examples**
 
-                 >>> metadata = {
-                 >>> client.deployments.ConfigurationMetaNames.NAME:"updated_Deployment",
-                 >>> client.deployments.ConfigurationMetaNames.ASSET: { "id": "ca0cd864-4582-4732-b365-3165598dc945", "rev":"2" }
-                 >>> }
-                 >>>
+                 >>> metadata = {client.deployments.ConfigurationMetaNames.NAME:"updated_Deployment"}
+                 >>> updated_deployment_details = client.deployments.update(deployment_uid, changes=metadata)
+
+                 >>> metadata = {client.deployments.ConfigurationMetaNames.ASSET: { "id": "ca0cd864-4582-4732-b365-3165598dc945",
+                 >>>                                                                "rev":"2" }}
                  >>> deployment_details = client.deployments.update(deployment_uid, changes=metadata)
 
         """
