@@ -30,6 +30,7 @@ from ibm_watson_machine_learning.utils.autoai.utils import check_dependencies_ve
     translate_batched_estimator_string_to_enum
 from ibm_watson_machine_learning.workspace import WorkSpace
 from ibm_watson_machine_learning.wml_client_error import ForbiddenActionForGitBasedProject
+from ibm_watson_machine_learning.messages.messages import Messages
 from .engines import WMLEngine
 from .optimizers import LocalAutoPipelines, RemoteAutoPipelines
 from .runs import AutoPipelinesRuns, LocalAutoPipelinesRuns
@@ -117,7 +118,7 @@ class AutoAI(BaseExperiment):
             self.runs = AutoPipelinesRuns(engine=WMLEngine(self._workspace))
             self.runs._workspace = self._workspace
 
-        self._block_autoai_on_git_based_project()
+        #self._block_autoai_on_git_based_project()
 
         self._init_estimator_enums()
 
@@ -477,6 +478,12 @@ class AutoAI(BaseExperiment):
             warn(
                 message="Support for excel sheet as number of the sheet (int) is deprecated! Please set excel sheet with name of the sheet.")
 
+        if data_join_graph is not None:
+            if self._workspace.wml_client.ICP:
+                print(Messages.get_message(message_id="obm_deprecation_message_cpd"))
+            #else:
+            #    print(Messages.get_message(message_id="obm_deprecation_message_cloud"))
+
         if prediction_type == PredictionType.FORECASTING and self._workspace.wml_client.ICP and \
                 (self._workspace.wml_client.wml_credentials['version'].startswith('2.5') or \
                         self._workspace.wml_client.wml_credentials['version'].startswith('3.0') or \
