@@ -154,6 +154,14 @@ class WMLEngine(BaseEngine):
                 self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
                     'pipelines'][0]['nodes'][0]['parameters']['optimization'][
                     'retrain_on_holdout'] = self._auto_pipelines_parameters.get('retrain_on_holdout')
+            if self._auto_pipelines_parameters.get('numerical_columns') is not None:
+                self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                    'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                    'numerical_columns'] = self._auto_pipelines_parameters.get('numerical_columns')
+            if self._auto_pipelines_parameters.get('categorical_columns') is not None:
+                self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                    'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                    'categorical_columns'] = self._auto_pipelines_parameters.get('categorical_columns')
         # end of section
 
         # pass fairness info for Cloud or CP4D 4.5
@@ -639,7 +647,7 @@ class WMLEngine(BaseEngine):
         self._current_run_id = run_params['metadata'].get('id', run_params['metadata'].get('guid'))
 
         if background_mode:
-            return self._wml_client.training.get_details(training_uid=self._current_run_id)
+            return self._wml_client.training.get_details(training_uid=self._current_run_id, _internal=True)
 
         else:
             wml_pipeline_details = self.get_params()
@@ -743,7 +751,7 @@ class WMLEngine(BaseEngine):
                 if disconnection_no >= attempts_no:
                     raise CannotConnectToWebsocket(attempts_no)
 
-            return self._wml_client.training.get_details(training_uid=self._current_run_id)
+            return self._wml_client.training.get_details(training_uid=self._current_run_id, _internal=True)
 
     def get_run_status(self) -> str:
         """
@@ -776,7 +784,7 @@ class WMLEngine(BaseEngine):
         if self._current_run_id is None:
             raise FitNeeded(reason="Firstly schedule a fit job by using the fit() method.")
 
-        details = self._wml_client.training.get_details(training_uid=self._current_run_id)
+        details = self._wml_client.training.get_details(training_uid=self._current_run_id, _internal=True)
 
         if include_metrics:
             return details
@@ -808,7 +816,7 @@ class WMLEngine(BaseEngine):
         if self._current_run_id is None:
             raise FitNeeded(reason="To list computed pipelines, first schedule a fit job by using the fit() method.")
 
-        details = self._wml_client.training.get_details(training_uid=self._current_run_id)
+        details = self._wml_client.training.get_details(training_uid=self._current_run_id, _internal=True)
         return create_summary(details=details, scoring=self._auto_pipelines_parameters['scoring'])
 
     def get_pipeline_details(self, pipeline_name: str = None) -> dict:
@@ -831,7 +839,7 @@ class WMLEngine(BaseEngine):
 
         if pipeline_name is None:
             pipeline_name = self.summary().index[0]
-        run_params = self._wml_client.training.get_details(training_uid=self._current_run_id)
+        run_params = self._wml_client.training.get_details(training_uid=self._current_run_id, _internal=True)
 
         pipeline_parameters = {
             "composition_steps": [],
@@ -1050,7 +1058,7 @@ class WMLEngine(BaseEngine):
             warnings.warn("OBM pipeline can be used only for inspection and deployment purposes.", Warning, stacklevel=2)
         # end note
 
-        run_params = self._wml_client.training.get_details(training_uid=self._current_run_id)
+        run_params = self._wml_client.training.get_details(training_uid=self._current_run_id, _internal=True)
 
         # note: recreation of s3 creds from connection asset
         results_reference = DataConnection._from_dict(run_params['entity']['results_reference'])
@@ -1110,7 +1118,7 @@ class WMLEngine(BaseEngine):
             warnings.warn("OBM pipeline notebook can be used only for inspection and deployment purposes.", Warning, stacklevel=2)
         # end note
 
-        run_params = self._wml_client.training.get_details(training_uid=self._current_run_id)
+        run_params = self._wml_client.training.get_details(training_uid=self._current_run_id, _internal=True)
 
         # note: recreation of s3 creds from connection asset
         results_reference = DataConnection._from_dict(run_params['entity']['results_reference'])
