@@ -32,6 +32,7 @@ from ibm_watson_machine_learning.utils.autoai.utils import (
     try_import_lale, create_summary, download_experiment_details_from_file, prepare_model_location_path,
     download_wml_pipeline_details_from_file, try_import_joblib)
 from ibm_watson_machine_learning.preprocessing import DataJoinGraph, DataJoinPipeline
+from ibm_watson_machine_learning.wml_client_error import WMLClientError
 
 from .base_auto_pipelines import BaseAutoPipelines
 
@@ -85,7 +86,7 @@ class LocalAutoPipelines(BaseAutoPipelines):
         List of estimators to include in computation process.
 
     cognito_transform_names: List['Transformers'], optional
-        List of transformers to include in feature enginnering computation process.
+        List of transformers to include in the feature enginnering computation process.
         See: AutoAI.Transformers
 
     _data_clients: List[Union['client', 'resource']], optional
@@ -108,7 +109,6 @@ class LocalAutoPipelines(BaseAutoPipelines):
                  max_num_daub_ensembles: int = 1,
                  train_sample_rows_test_size: float = 1.,
                  include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms']] = None,
-                 include_batched_ensemble_estimators: List[Union['BatchedClassificationAlgorithms', 'BatchedRegressionAlgorithms']] = None,
                  cognito_transform_names: List['Transformers'] = None,
                  positive_label: str = None,
                  _data_clients: List[Tuple['DataConnection', 'resource']] = None,
@@ -158,7 +158,6 @@ class LocalAutoPipelines(BaseAutoPipelines):
                 'max_num_daub_ensembles': int(max_num_daub_ensembles),
                 'train_sample_rows_test_size': train_sample_rows_test_size,
                 'include_only_estimators': include_only_estimators,
-                'include_batched_ensemble_estimators': include_batched_ensemble_estimators,
                 'cognito_transform_names': cognito_transform_names,
                 'positive_label': positive_label
             }
@@ -522,6 +521,11 @@ class LocalAutoPipelines(BaseAutoPipelines):
             raise ValueError('Incorrect value of \'astype\'. '
                              'Should be either PipelineTypes.SKLEARN or PipelineTypes.LALE')
 
+    def get_pipeline_notebook(self,
+                     pipeline_name: str = None,
+                     persist: 'bool' = False) -> Union['Pipeline', 'TrainablePipeline']:
+        raise WMLClientError("Not supported in local scenario.")
+
     def predict(self, X: Union['DataFrame', 'ndarray']) -> 'ndarray':
         """
         Predict method called on top of the best computed pipeline.
