@@ -39,6 +39,7 @@ from ibm_watson_machine_learning.utils.autoai.wsd_ui import (
 from ibm_watson_machine_learning.utils.autoai.connection import validate_source_data_connections, \
     validate_results_data_connection
 from ibm_watson_machine_learning.utils import DisableWarningsLogger
+from ibm_watson_machine_learning.messages.messages import Messages
 from .base_auto_pipelines import BaseAutoPipelines
 
 if TYPE_CHECKING:
@@ -170,6 +171,8 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                  feature_columns: List[str] = None,
                  pipeline_types: List['ForecastingPipelineTypes'] = None,
                  supporting_features_at_forecast: bool = None,
+                 categorical_columns: list = None,
+                 numerical_columns: list = None,
                  **kwargs):
 
         if data_join_graph is not None:
@@ -227,7 +230,9 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             'retrain_on_holdout': retrain_on_holdout,
             'feature_columns': feature_columns,
             'pipeline_types': pipeline_types,
-            'supporting_features_at_forecast': supporting_features_at_forecast
+            'supporting_features_at_forecast': supporting_features_at_forecast,
+            'numerical_columns': numerical_columns,
+            'categorical_columns':categorical_columns,
         }
 
         if fairness_info:
@@ -347,6 +352,12 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         >>>     ),
         >>>     background_mode=False)
         """
+        if self.params.get('data_join_graph'):
+            if self._workspace.wml_client.ICP:
+                print(Messages.get_message(message_id="obm_deprecation_message_cpd"))
+            #else:
+            #    print(Messages.get_message(message_id="obm_deprecation_message_cloud"))
+
         if training_data_references is not None:
             training_data_reference = training_data_references
 
@@ -556,7 +567,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         """
         return self._engine.get_run_status()
 
-    def get_run_details(self, include_metrics: bool = False) -> dict:
+    def get_run_details(self, include_metrics: bool = False, _internal=False) -> dict:
         """
         Get fit/run details.
 
@@ -577,6 +588,12 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         >>>
         >>> remote_optimizer.get_run_details()
         """
+        if not _internal and self.params.get('data_join_graph'):
+            if self._workspace.wml_client.ICP:
+                print(Messages.get_message(message_id="obm_deprecation_message_cpd"))
+            #else:
+            #    print(Messages.get_message(message_id="obm_deprecation_message_cloud"))
+
         return self._engine.get_run_details(include_metrics=include_metrics)
 
     def cancel_run(self) -> None:
@@ -886,12 +903,12 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             user_holdout_exists = False
 
         optimizer_parameters = self.get_params()
-        training_data_references = self.get_run_details()['entity']['training_data_references']
+        training_data_references = self.get_run_details(_internal=True)['entity']['training_data_references']
 
         data_connections = [
             DataConnection._from_dict(_dict=data_connection) for data_connection in training_data_references]
 
-        run_details = self.get_run_details(include_metrics=True)
+        run_details = self.get_run_details(include_metrics=True, _internal=True)
 
         for data_connection in data_connections:  # note: populate DataConnections with optimizer params
             data_connection.auto_pipeline_params = deepcopy(optimizer_parameters)
@@ -915,7 +932,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         List['DataConnection'] with populated optimizer parameters
         """
         optimizer_parameters = self.get_params()
-        run_details = self.get_run_details()
+        run_details = self.get_run_details(_internal=True)
 
         if not run_details['entity'].get('test_data_references'):
             raise TestDataNotPresent(reason="User specified test data was not present in this experiment. "
@@ -975,7 +992,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
 
         if optimizer_parameters['data_join_graph']:
             details = self._engine._wml_client.training.get_details(
-                training_uid=self._engine._current_run_id)
+                training_uid=self._engine._current_run_id, _internal=True)
 
             path = details['entity']['results_reference']['location'].get(
                 'path',
@@ -1013,7 +1030,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
 
         if optimizer_parameters['data_join_graph']:
             details = self._engine._wml_client.training.get_details(
-                training_uid=self._engine._current_run_id)
+                training_uid=self._engine._current_run_id, _internal=True)
 
             path = details['entity']['test_output_data']['location'].get(
                 'path',
