@@ -68,7 +68,7 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
         wml_pipelines_types = []
 
         # note: download all runs details
-        runs_details = self._wml_engine._wml_client.training.get_details(limit=50)
+        runs_details = self._wml_engine._wml_client.training.get_details(limit=50, _internal=True)
         data = runs_details.get('resources', [])
         run_details_generator = NextRunDetailsGenerator(wml_client=self._wml_engine._wml_client,
                                                         href=runs_details.get('next', {'href': None}).get('href'))
@@ -156,12 +156,12 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
 
         if run_id is None:
             optimizer_id = self._wml_engine._wml_client.training.get_details(
-                limit=1
+                limit=1, _internal=True
             ).get('resources')[0]['entity']['pipeline']['id']
 
         else:
             optimizer_id = self._wml_engine._wml_client.training.get_details(
-                training_uid=run_id
+                training_uid=run_id, _internal=True
             ).get('entity')['pipeline']['id']
 
         optimizer_config = self._wml_engine._wml_client.pipelines.get_details(pipeline_uid=optimizer_id)
@@ -334,10 +334,10 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
         >>> experiment.runs.get_run_details()
         """
         if run_id is None:
-            details = self._wml_engine._wml_client.training.get_details(limit=1).get('resources')[0]
+            details = self._wml_engine._wml_client.training.get_details(limit=1, _internal=True).get('resources')[0]
 
         else:
-            details = self._wml_engine._wml_client.training.get_details(training_uid=run_id)
+            details = self._wml_engine._wml_client.training.get_details(training_uid=run_id, _internal=True)
 
         if details['entity']['status'].get('metrics', False):
             del details['entity']['status']['metrics']
