@@ -777,9 +777,14 @@ class BaseDataConnection(ABC):
         try:
             file = cos_client.Object(self.location.bucket,
                                      location).get()
-        except:
-            file = list(cos_client.Bucket(self.location.bucket).objects.filter(
-                Prefix=location))[0].get()
+        except Exception as e:
+            cos_objects_list = list(cos_client.Bucket(self.location.bucket).objects.filter(
+                Prefix=location))
+            if len(cos_objects_list) > 0:
+                file = list(cos_client.Bucket(self.location.bucket).objects.filter(
+                    Prefix=location))[0].get()
+            else:
+                raise e
 
         buffer = io.BytesIO(file['Body'].read())
         data = try_load_dataset(buffer=buffer,
