@@ -58,6 +58,7 @@ from ibm_watson_machine_learning.utils.autoai.utils import all_logging_disabled,
 from ibm_watson_machine_learning.utils.autoai.watson_studio import get_project
 from ibm_watson_machine_learning.data_loaders.datasets.experiment import DEFAULT_SAMPLING_TYPE, DEFAULT_SAMPLE_SIZE_LIMIT
 from ibm_watson_machine_learning.wml_client_error import MissingValue, ApiRequestFailure, WMLClientError
+from ibm_watson_machine_learning.utils.autoai.errors import ContainerTypeNotSupported
 from .base_connection import BaseConnection
 from .base_data_connection import BaseDataConnection
 from .base_location import BaseLocation
@@ -411,7 +412,7 @@ class DataConnection(BaseDataConnection):
 
             # Note: When lookback window is auto detected there is need to get the detected value from training details
             if self.auto_pipeline_params.get('lookback_window') == -1 or self.auto_pipeline_params.get('lookback_window') is None:
-                ts_metrics = self._wml_client.training.get_details(self.auto_pipeline_params.get('run_id'))['entity']['status']['metrics']
+                ts_metrics = self._wml_client.training.get_details(self.auto_pipeline_params.get('run_id'), _internal=True)['entity']['status']['metrics']
                 final_ts_state_name = "after_final_pipelines_generation"
 
 
@@ -806,6 +807,9 @@ class DataConnection(BaseDataConnection):
                 data = self._download_training_data_from_file_system()
 
         elif self.type == DataConnectionTypes.CA or self.type == DataConnectionTypes.CN:
+            if getattr(self._wml_client, 'ICP', False) and self.type == DataConnectionTypes.CN:
+                raise ContainerTypeNotSupported()  # block Container type on CPD
+
             if use_flight and not self._obm:
                 # Workaround for container connection type, we need to fetch COS details from space/project
                 if self.type == DataConnectionTypes.CN:
@@ -953,6 +957,9 @@ class DataConnection(BaseDataConnection):
             raise ConnectionError("S3 DataConnection is deprecated! Please use data_asset_id instead.")
 
         elif self.type == DataConnectionTypes.CA or self.type == DataConnectionTypes.CN:
+            if getattr(self._wml_client, 'ICP', False) and self.type == DataConnectionTypes.CN:
+                raise ContainerTypeNotSupported()  # block Container type on CPD
+
             if self._check_if_connection_asset_is_s3():
                 # do not try Flight if we are on the cloud
                 if self._wml_client is not None and not self._wml_client.ICP and not use_flight:  # CLOUD
@@ -1183,6 +1190,9 @@ class S3Location(BaseLocation):
     path: str, required
         COS data path in the bucket.
 
+    excel_sheet: str, optional
+        Name of excel sheet if pointed dataset is excel file used for Batched Deployment scoring.
+
     model_location: str, optional
         Path to the pipeline model in the COS.
 
@@ -1200,6 +1210,10 @@ class S3Location(BaseLocation):
         if kwargs.get('training_status') is not None:
             self._training_status = kwargs['training_status']
 
+        if kwargs.get('excel_sheet') is not None:
+            self.sheet_name = kwargs['excel_sheet']
+            self.file_format = "xls"
+
     def _get_file_size(self, cos_resource_client: 'resource') -> 'int':
         try:
             size = cos_resource_client.Object(self.bucket, self.path).content_length
