@@ -207,6 +207,7 @@ class FlightConnection:
             override_hostname=self.flight_location,
             **additional_connection_args
         )
+        self.min_rows = self.params.get('min_rows', 100)
 
         # note: client as property and setter for dynamic href creation for AssetLocation
 
@@ -486,8 +487,8 @@ class FlightConnection:
         """Process data columns and log data size"""
         logger.debug(f"Process data: Casting string data to numerical columns")
         data = self._cast_columns_to_float_64(data)
-        if len(data) < 100 and self.enable_subsampling:
-            raise ValueError(f"We do not have enough rows {len(data)} / minimum 100")
+        if len(data) < self.min_rows and self.enable_subsampling:
+            raise ValueError(f"We do not have enough rows {len(data)} / minimum {self.min_rows}")
 
         logger.debug(f"BATCH SIZE: {sys.getsizeof(data)} Bytes")
         return data
