@@ -57,17 +57,12 @@ class HwSpec(WMLResource):
 
         """
         HwSpec._validate_type(hw_spec_uid, u'hw_spec_uid', STR_TYPE, True)
-        if not self._ICP:
+        if not self._ICP or self._client.ICP_PLATFORM_SPACES:
             response = requests.get(self._client.service_instance._href_definitions.get_hw_spec_href(hw_spec_uid), params=self._client._params(skip_space_project_chk=True),
                                     headers=self._client._get_headers())
         else:
-            if self._client.ICP_PLATFORM_SPACES:
-                response = requests.get(self._client.service_instance._href_definitions.get_hw_spec_href(hw_spec_uid),
-                                        params=self._client._params(skip_space_project_chk=True),
-                                        headers=self._client._get_headers())
-            else:
-                response = requests.get(self._client.service_instance._href_definitions.get_hw_spec_href(hw_spec_uid), params=self._client._params(),
-                                          headers=self._client._get_headers())
+            response = requests.get(self._client.service_instance._href_definitions.get_hw_spec_href(hw_spec_uid), params=self._client._params(),
+                                      headers=self._client._get_headers())
 
         if response.status_code == 200:
             return self._get_required_element_from_response(self._handle_response(200, u'get hardware spec details', response))
@@ -116,10 +111,7 @@ class HwSpec(WMLResource):
     #     hw_spec_meta_json = json.dumps(hw_spec_meta)
     #     href = self._client.service_instance._href_definitions.get_hw_specs_href()
     #
-    #     if not self._ICP:
-    #         creation_response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(), data=hw_spec_meta_json)
-    #     else:
-    #         creation_response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(), data=hw_spec_meta_json)
+    #     creation_response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(), data=hw_spec_meta_json)
     #
     #     hw_spec_details = self._handle_response(201, u'creating new hw specs', creation_response)
     #
@@ -155,11 +147,9 @@ class HwSpec(WMLResource):
 
         # Todo provide api to return
         href = self._client.service_instance._href_definitions.get_hw_specs_href()
-        # Todo include space_id/project_id once https://github.ibm.com/ax/planning/issues/7493 is fixed
-        if not self._ICP:
-            response = requests.get(href, params, headers=self._client._get_headers())
-        else:
-            response = requests.get(href, headers=self._client._get_headers())
+
+        response = requests.get(href, params, headers=self._client._get_headers())
+
         self._handle_response(200, u'list hw_specs', response)
         asset_details = self._handle_response(200, u'list assets', response)["resources"]
         hw_spec_values = [
@@ -311,14 +301,11 @@ class HwSpec(WMLResource):
         HwSpec._validate_type(hw_spec_name, u'hw_spec_name', STR_TYPE, True)
         parameters = self._client._params(skip_space_project_chk=True)
         parameters.update(name=hw_spec_name)
-        if not self._ICP:
-            response = requests.get(self._client.service_instance._href_definitions.get_hw_specs_href(),
-                                    params=parameters,
-                                    headers=self._client._get_headers())
-        else:
-            response = requests.get(self._client.service_instance._href_definitions.get_hw_specs_href(),
-                                    params=parameters,
-                                    headers=self._client._get_headers())
+
+        response = requests.get(self._client.service_instance._href_definitions.get_hw_specs_href(),
+                                params=parameters,
+                                headers=self._client._get_headers())
+
         if response.status_code == 200:
             total_values = self._handle_response(200, u'list assets', response)["total_results"]
             if total_values != 0:
@@ -350,12 +337,9 @@ class HwSpec(WMLResource):
     #     """
     #     HwSpec._validate_type(hw_spec_uid, u'hw_spec_uid', STR_TYPE, True)
     #
-    #     if not self._ICP:
-    #         response = requests.delete(self._client.service_instance._href_definitions.get_hw_spec_href(hw_spec_uid), params=self._client._params(),
-    #                                 headers=self._client._get_headers())
-    #     else:
-    #         response = requests.delete(self._client.service_instance._href_definitions.get_hw_spec_href(hw_spec_uid), params=self._client._params(),
-    #                                   headers=self._client._get_headers())
+    #     response = requests.delete(self._client.service_instance._href_definitions.get_hw_spec_href(hw_spec_uid), params=self._client._params(),
+    #                             headers=self._client._get_headers())
+    #
     #     if response.status_code == 200:
     #         return self._get_required_element_from_response(response.json())
     #     else:
