@@ -76,19 +76,19 @@ class Import(WMLResource):
 
         # file_handler = {'file.zip': open(file_path,'rb')}
 
-        file = open(file_path, 'rb')
+        with open(file_path, 'rb') as file:
 
-        # from datetime import datetime
-        # start_time = datetime.now()
-        #
-        data = file.read()
-        #
-        # end_time = datetime.now()
-        #
-        # dt = end_time - start_time
-        # ms = (dt.days * 24 * 60 * 60 + dt.seconds) * 1000 + dt.microseconds / 1000.0
+            # from datetime import datetime
+            # start_time = datetime.now()
+            #
+            data = file.read()
+            #
+            # end_time = datetime.now()
+            #
+            # dt = end_time - start_time
+            # ms = (dt.days * 24 * 60 * 60 + dt.seconds) * 1000 + dt.microseconds / 1000.0
 
-        # print("Time taken to read the zip file in ms: {}".format(ms))
+            # print("Time taken to read the zip file in ms: {}".format(ms))
 
         href = self._client.service_instance._href_definitions.imports_href()
 
