@@ -36,9 +36,9 @@ class ServiceInstance:
             else:
                 self._wml_credentials[u'url'] = self.get_url() + ':31843'
             self._wml_credentials[u'instance_id'] = "999"
-        self._href_definitions = HrefDefinitions(self._wml_credentials)
+        self._href_definitions = HrefDefinitions(self._client)
         self._client.wml_token = self._create_token()
-        self._logger.info(u'Successfully prepared token: ' + self._client.wml_token)
+        # self._logger.info(u'Successfully prepared token: ' + self._client.wml_token)
         # ml_repository_client is initialized in repo
         self.details = None
 
