@@ -137,7 +137,10 @@ class SWSReceiver(FLReceiver):
         logger.debug("METHOD = SWSReceiver.start")
         self.loop = asyncio.new_event_loop()
         self.stop = self.loop.create_future()
-        self.loop.add_signal_handler(signal.SIGTERM, self.stop.set_result, None)
+        try:
+            self.loop.add_signal_handler(signal.SIGTERM, self.stop.set_result, None)
+        except NotImplementedError:
+            logger.debug("Signal handling is not implemented")
         t1 = threading.Thread(target=self.setup_websocket_connection, args=(self.loop, self.stop), daemon=True)
         t1.start()
        
@@ -223,6 +226,14 @@ class SWSReceiver(FLReceiver):
                 logger.error(str(ex))
                 self.stopped = True
                 continue
+            except ssl.SSLError as ex:
+                logger.info("SSL Error encountered.")
+                pRecvEvt.set()
+                logger.error(str(ex))
+                raise Exception("No valid certificate detected. Please replace the default certificate with your own "
+                                  "TLS certificate, or set verify to False at your own risk. For more details, please see "
+                                  "https://www.ibm.com/docs/en/cloud-paks/cp-data/4.0?topic=client-using-custom-tls-certificate-connect-platform")
+
             except Exception as ex:
                 logger.info("Exception encountered.")
                 logger.error(str(ex))
