@@ -231,7 +231,7 @@ class Party(WMLResource):
         if ( experiment_id is not None ):
             while True: 
                 try:
-                    details = self._client.training.get_details(get_all=True,training_definition_id=experiment_id)['resources']
+                    details = self._client.training.get_details(get_all=True,training_definition_id=experiment_id, _internal=True)['resources']
                     details = [ d for d in details if d['entity']['status']['state'] in ['accepting_parties','pending','running'] ]
                     if not details :
                         if timeout_time and timeout_time < time.time() :
@@ -299,7 +299,7 @@ class Party(WMLResource):
 
             if ready:
                 if "cpd406" in self.module_location or "cloud" in self.module_location:
-                    details = self._client.training.get_details(aggregator_id)
+                    details = self._client.training.get_details(aggregator_id, _internal=True)
                     fl_entity = details["entity"]["federated_learning"]
                     if "software_spec" in fl_entity:
                         software_spec = fl_entity["software_spec"]["name"] if "name" in fl_entity["software_spec"] else fl_entity["software_spec"]["id"]
