@@ -115,7 +115,7 @@ class Pipelines(WMLResource):
                   }
                 ]
               }
-        if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_35 or self._client.ICP_40:
+        if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_35 or self._client.ICP_40 or self._client.ICP_45:
             if self.ConfigurationMetaNames.COMMAND in meta_props:
                 doc["pipelines"][0]["nodes"][0]["parameters"]["command"] = meta_props[self.ConfigurationMetaNames.COMMAND]
             if self.ConfigurationMetaNames.RUNTIMES in meta_props:
@@ -199,7 +199,7 @@ class Pipelines(WMLResource):
             else:
                 raise WMLClientError("It is mandatory to set the space/project id. Use client.set.default_space(<SPACE_UID>)/client.set.default_project(<PROJECT_UID>) to proceed.")
 
-        if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_35 or self._client.ICP_40:
+        if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_35 or self._client.ICP_40 or self._client.ICP_45:
             if self._client.default_space_id is not None:
                 pipeline_meta['space_id'] = self._client.default_space_id
             elif self._client.default_project_id is not None:
@@ -282,7 +282,7 @@ class Pipelines(WMLResource):
                 pipeline_details = self._handle_response(201, u'creating new pipeline', creation_response)
                 return WMLResource._wsd_get_required_element_from_response(self, pipeline_details)
 
-            elif self._client.ICP_35 or self._client.ICP_40:
+            elif self._client.ICP_35 or self._client.ICP_40 or self._client.ICP_45:
                 creation_response = requests.post(
                     self._client.service_instance._href_definitions.get_pipelines_href(),
                     headers=self._client._get_headers(),
@@ -316,7 +316,8 @@ class Pipelines(WMLResource):
         pipeline_uid = str_type_conv(pipeline_uid)
         Pipelines._validate_type(pipeline_uid, u'pipeline_uid', STR_TYPE, False)
 
-        if not self._client.ICP_30 and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_35 and not self._client.ICP_40:
+        if not any([self._client.ICP_30, self._client.CLOUD_PLATFORM_SPACES, self._client.ICP_35, self._client.ICP_40,
+                    self._client.ICP_45]):
             raise WMLClientError(
                 u'Revision support is not there in this version WML server. It is supported only from 3.1.0 onwards.')
         else:
@@ -493,7 +494,8 @@ class Pipelines(WMLResource):
         pipeline_uid = str_type_conv(pipeline_uid)
         Pipelines._validate_type(pipeline_uid, u'pipeline_uid', STR_TYPE, True)
         Pipelines._validate_type(rev_uid, u'rev_uid', int, True)
-        if not self._client.ICP_30 and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_35 and not self._client.ICP_40:
+        if not any([self._client.ICP_30, self._client.CLOUD_PLATFORM_SPACES, self._client.ICP_35, self._client.ICP_40,
+                    self._client.ICP_45]):
             raise WMLClientError(
                 'Not supported. Revisions APIs are supported only for IBM Cloud Pak® for Data 3.0 and above.')
         else:
@@ -630,7 +632,7 @@ class Pipelines(WMLResource):
             self._client._check_if_either_is_set()
 
             pipeline_resources = self.get_details(limit=limit)[u'resources']
-            if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_35 or self._client.ICP_40:
+            if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_35 or self._client.ICP_40 or self._client.ICP_45:
                 pipeline_values = [(m[u'metadata'][u'id'], m[u'metadata'][u'name'], m[u'metadata'][u'created_at']) for m
                                    in pipeline_resources]
 
@@ -664,7 +666,8 @@ class Pipelines(WMLResource):
 
         Pipelines._validate_type(pipeline_uid, u'pipeline_uid', STR_TYPE, True)
 
-        if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_35 and not self._client.ICP_40:
+        if not any([self._client.ICP_30, self._client.CLOUD_PLATFORM_SPACES, self._client.ICP_35, self._client.ICP_40,
+                    self._client.ICP_45]):
             raise WMLClientError(
                 u'Revision support is not there in this WML server. It is supported only from 3.1.0 onwards.')
         else:
@@ -717,7 +720,7 @@ class Pipelines(WMLResource):
                     * Space id is mandatory for move action\n
 
         """
-        if self._client.WSD or self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_35 or self._client.ICP_40:
+        if any([self._client.WSD, self._client.CLOUD_PLATFORM_SPACES, self._client.ICP_35, self._client.ICP_40, self._client.ICP_45]):
             raise WMLClientError(" Clone pipeline operation is not supported. ")
         artifact = str_type_conv(pipeline_uid)
         Pipelines._validate_type(artifact, 'exp_id', STR_TYPE, True)
