@@ -902,9 +902,11 @@ class Repository(WMLResource):
             return self._client._models.download(artifact_uid, filename, rev_uid,format)
         elif res['function'] is True:
             return self._client._functions.download(artifact_uid, filename, rev_uid)
-        elif not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_35 and not self._client.ICP_40 and res['library'] is True:
+        elif not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_35 and not self._client.ICP_40  \
+                and not self._client.ICP_45 and res['library'] is True:
             return self._client.runtimes.download_library(artifact_uid, filename)
-        elif not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_35 and not self._client.ICP_40 and res['runtime'] is True:
+        elif not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_35 and not self._client.ICP_40 \
+                and not self._client.ICP_45 and res['runtime'] is True:
             return self._client.runtimes.download_configuration(artifact_uid, filename)
         else:
             raise WMLClientError('Unexpected type of artifact to download or Artifact with artifact_uid: \'{}\' does not exist.'.format(artifact_uid) )
