@@ -96,21 +96,15 @@ class SwSpec(WMLResource):
         SwSpec._validate_type(sw_spec_uid, u'sw_spec_uid', STR_TYPE, False)
 
         if sw_spec_uid:
-            if not self._ICP:
+            if not self._ICP or self._client.ICP_PLATFORM_SPACES:
                 response = requests.get(self._client.service_instance._href_definitions.get_sw_spec_href(sw_spec_uid),
                                         params=self._client._params(skip_space_project_chk=True),
                                         headers=self._client._get_headers())
             else:
-                if self._client.ICP_PLATFORM_SPACES:
-                    response = requests.get(
-                        self._client.service_instance._href_definitions.get_sw_spec_href(sw_spec_uid),
-                        params=self._client._params(skip_space_project_chk=True),
-                        headers=self._client._get_headers())
-                else:
-                    response = requests.get(
-                        self._client.service_instance._href_definitions.get_sw_spec_href(sw_spec_uid),
-                        params=self._client._params(),
-                        headers=self._client._get_headers())
+                response = requests.get(
+                    self._client.service_instance._href_definitions.get_sw_spec_href(sw_spec_uid),
+                    params=self._client._params(),
+                    headers=self._client._get_headers())
 
             if response.status_code == 200:
                 return self._get_required_element_from_response(
@@ -118,21 +112,15 @@ class SwSpec(WMLResource):
             else:
                 return self._handle_response(200, u'get sw spec details', response)
         else:
-            if not self._ICP:
+            if not self._ICP or self._client.ICP_PLATFORM_SPACES:
                 response = requests.get(self._client.service_instance._href_definitions.get_sw_specs_href(),
                                         params=self._client._params(skip_space_project_chk=True),
                                         headers=self._client._get_headers())
             else:
-                if self._client.ICP_PLATFORM_SPACES:
-                    response = requests.get(
-                        self._client.service_instance._href_definitions.get_sw_specs_href(),
-                        params=self._client._params(skip_space_project_chk=True),
-                        headers=self._client._get_headers())
-                else:
-                    response = requests.get(
-                        self._client.service_instance._href_definitions.get_sw_specs_href(),
-                        params=self._client._params(),
-                        headers=self._client._get_headers())
+                response = requests.get(
+                    self._client.service_instance._href_definitions.get_sw_specs_href(),
+                    params=self._client._params(),
+                    headers=self._client._get_headers())
 
             if response.status_code == 200:
                 return {'resources': [self._get_required_element_from_response(x)
@@ -184,10 +172,7 @@ class SwSpec(WMLResource):
         sw_spec_meta_json = json.dumps(sw_spec_meta)
         href = self._client.service_instance._href_definitions.get_sw_specs_href()
 
-        if not self._ICP:
-            creation_response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(), data=sw_spec_meta_json)
-        else:
-            creation_response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(), data=sw_spec_meta_json)
+        creation_response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(), data=sw_spec_meta_json)
 
         sw_spec_details = self._handle_response(201, u'creating sofware specifications', creation_response)
 
@@ -217,10 +202,9 @@ class SwSpec(WMLResource):
 
         if not self._client.WSD_20:
             href = self._client.service_instance._href_definitions.get_sw_specs_href()
-            if not self._ICP:
-                response = requests.get(href, params=self._client._params(), headers=self._client._get_headers())
-            else:
-                response = requests.get(href, params=self._client._params(), headers=self._client._get_headers())
+
+            response = requests.get(href, params=self._client._params(), headers=self._client._get_headers())
+
             self._handle_response(200, u'list sw_specs', response)
             asset_details = self._handle_response(200, u'list assets', response)["resources"]
             sw_spec_values = [
@@ -353,15 +337,10 @@ class SwSpec(WMLResource):
         if not self._client.WSD_20:
             parameters = self._client._params(skip_space_project_chk=True)
             parameters.update(name=sw_spec_name)
-            if not self._ICP:
-                response = requests.get(self._client.service_instance._href_definitions.get_sw_specs_href(),
-                                        params=parameters,
-                                        headers=self._client._get_headers())
-            else:
 
-                response = requests.get(self._client.service_instance._href_definitions.get_sw_specs_href(),
-                                        params=parameters,
-                                        headers=self._client._get_headers())
+            response = requests.get(self._client.service_instance._href_definitions.get_sw_specs_href(),
+                                    params=parameters,
+                                    headers=self._client._get_headers())
 
             total_values = self._handle_response(200, u'list assets', response)["total_results"]
             if total_values != 0:
@@ -430,12 +409,9 @@ class SwSpec(WMLResource):
 
         SwSpec._validate_type(sw_spec_uid, u'sw_spec_uid', STR_TYPE, True)
 
-        if not self._ICP:
-            response = requests.delete(self._client.service_instance._href_definitions.get_sw_spec_href(sw_spec_uid), params=self._client._params(),
-                                    headers=self._client._get_headers())
-        else:
-            response = requests.delete(self._client.service_instance._href_definitions.get_sw_spec_href(sw_spec_uid), params=self._client._params(),
-                                      headers=self._client._get_headers())
+        response = requests.delete(self._client.service_instance._href_definitions.get_sw_spec_href(sw_spec_uid), params=self._client._params(),
+                                headers=self._client._get_headers())
+
         if response.status_code == 200:
             return self._get_required_element_from_response(response.json())
         else:
@@ -476,11 +452,7 @@ class SwSpec(WMLResource):
 
         url = url + "/package_extensions/" + pkg_extn_id
 
-
-        if not self._ICP:
-            response = requests.put(url, params=self._client._params(), headers=self._client._get_headers())
-        else:
-            response = requests.put(url,  params=self._client._params(), headers=self._client._get_headers())
+        response = requests.put(url, params=self._client._params(), headers=self._client._get_headers())
 
         if response.status_code == 204:
             print("SUCCESS")
