@@ -27,6 +27,8 @@ from warnings import warn
 from ibm_watson_machine_learning.wml_resource import WMLResource
 from ibm_boto3.exceptions import Boto3Error
 
+from ibm_watson_machine_learning.messages.messages import Messages
+
 logging.getLogger('lomond').setLevel(logging.CRITICAL)
 
 
@@ -81,7 +83,7 @@ class Training(WMLResource):
         training_uid = str_type_conv(training_uid)
         Training._validate_type(training_uid, 'training_uid', STR_TYPE, True)
 
-        details = self.get_details(training_uid)
+        details = self.get_details(training_uid, _internal=True)
 
         if details is not None:
             return WMLResource._get_required_element_from_dict(details, u'details', [u'entity', u'status'])
@@ -90,7 +92,7 @@ class Training(WMLResource):
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_details(self, training_uid=None, limit=None, asynchronous=False, get_all=False, training_type=None,
-                    state=None, tag_value=None, training_definition_id=None):
+                    state=None, tag_value=None, training_definition_id=None, _internal=False):
         """
         Get metadata of training(s). If training_uid is not specified returns all model spaces metadata.
 
@@ -161,7 +163,15 @@ class Training(WMLResource):
             return self._get_artifact_details(url, training_uid, limit, 'trained models', _async=asynchronous,
                                               _all=get_all, query_params=query_params)
         else:
-            return self._get_artifact_details(url, training_uid, limit, 'trained models')
+            details = self._get_artifact_details(url, training_uid, limit, 'trained models')
+
+            if not _internal and details.get('entity', {}).get('status', {}).get('feature_engineering_components', {}).get('obm'):
+                if self._client.ICP:
+                    print(Messages.get_message(message_id="obm_deprecation_message_cpd"))
+                #else:
+                #    print(Messages.get_message(message_id="obm_deprecation_message_cloud"))
+
+            return details
 
     @staticmethod
     @docstring_parameter({'str_type': STR_TYPE_NAME})
@@ -568,7 +578,7 @@ class Training(WMLResource):
                 print(u'\nTraining of \'{}\' failed with status: \'{}\'.'.format(trained_model_guid, str(status)))
 
             self._logger.debug(u'Response({}): {}'.format(state, run_details))
-            return self.get_details(trained_model_guid)
+            return self.get_details(trained_model_guid, _internal=True)
 
     def list(self, limit=None, asynchronous=False, get_all=False):
         """
@@ -611,10 +621,10 @@ class Training(WMLResource):
 
         if asynchronous:
             return (preprocess_details(details) for details in self.get_details(
-                limit=limit, asynchronous=asynchronous, get_all=get_all))
+                limit=limit, asynchronous=asynchronous, get_all=get_all, _internal=True))
 
         else:
-            details = self.get_details(limit=limit, get_all=get_all)
+            details = self.get_details(limit=limit, get_all=get_all, _internal=True)
             return preprocess_details(details)
 
     def list_subtrainings(self, training_uid):
@@ -643,7 +653,7 @@ class Training(WMLResource):
             raise WMLClientError("Sub-trainings are no longer available for trainings, please use list_intermediate_models().")
 
         self._client._check_if_either_is_set()
-        details = self.get_details(training_uid)
+        details = self.get_details(training_uid, _internal=True)
         if "experiment" not in details["entity"]:
             raise WMLClientError("Sub-trainings are available for training created via experiment only.")
         details_parent = requests.get(
@@ -688,7 +698,7 @@ class Training(WMLResource):
             raise WMLClientError("This method is not supported for IBM Cloud Pak® for Data. " )
 
         self._client._check_if_either_is_set()
-        details = self.get_details(training_uid)
+        details = self.get_details(training_uid, _internal=True)
         #if status is completed then only lists only global_output else display message saying "state value"
         training_state = details[u'entity'][u'status'][u'state']
         if(training_state=='completed'):
@@ -794,7 +804,7 @@ class Training(WMLResource):
 
     def _COS_logs(self, run_uid,on_start=lambda: {}):
         on_start()
-        run_details = self.get_details(run_uid)
+        run_details = self.get_details(run_uid, _internal=True)
         if 'connection' in run_details["entity"]["results_reference"] and run_details["entity"]["results_reference"].get("connection") is not None:
             endpoint_url = run_details["entity"]["results_reference"]["connection"]["endpoint_url"]
             aws_access_key = run_details["entity"]["results_reference"]["connection"]["access_key_id"]
@@ -856,7 +866,7 @@ class Training(WMLResource):
 
     def _COS_metrics(self, run_uid,on_start=lambda: {}):
         on_start()
-        run_details = self.get_details(run_uid)
+        run_details = self.get_details(run_uid, _internal=True)
         endpoint_url = run_details["entity"]["results_reference"]["connection"]["endpoint_url"]
         aws_access_key = run_details["entity"]["results_reference"]["connection"]["access_key_id"]
         aws_secret = run_details["entity"]["results_reference"]["connection"]["secret_access_key"]
@@ -950,7 +960,7 @@ class Training(WMLResource):
 
     def _simple_monitor_logs(self, training_uid, on_start=lambda: {}):
         try:
-            run_details = self.get_details(training_uid)
+            run_details = self.get_details(training_uid, _internal=True)
         except ApiRequestFailure as ex:
             if "404" in str(ex.args[1]):
                 print("Could not find the training run details for the given training run id. ")
@@ -1035,7 +1045,7 @@ class Training(WMLResource):
         training_uid = str_type_conv(training_uid)
         Training._validate_type(training_uid, u'training_uid', STR_TYPE, True)
         try:
-            run_details = self.get_details(training_uid)
+            run_details = self.get_details(training_uid, _internal=True)
         except ApiRequestFailure as ex:
             if "404" in str(ex.args[1]):
                 print("Could not find the training run details for the given training run id. ")
@@ -1119,7 +1129,7 @@ class Training(WMLResource):
         if 'metrics' in status:
             return status['metrics']
         else:
-            details = self.get_details(training_uid)
+            details = self.get_details(training_uid, _internal=True)
             if 'metrics' in details:
                 return details['metrics']
             else:
