@@ -21,7 +21,7 @@ import base64
 import json
 from typing import Any, Dict, Tuple, List, TYPE_CHECKING
 
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 
 from ibm_watson_machine_learning.href_definitions import IAM_TOKEN_API, HrefDefinitions
 from ibm_watson_machine_learning.wml_client_error import ApiRequestFailure
