@@ -208,7 +208,7 @@ def save_computed_pipelines_for_ui(wml_client: 'APIClient', run_id: str) -> None
     project = get_project()
     project_id = project.get_metadata()["metadata"]["guid"]
 
-    training_details = wml_client.training.get_details(run_id)
+    training_details = wml_client.training.get_details(run_id, _internal=True)
 
     # note: prepare needed information to fetch data
     path = training_details['entity']['results_reference']['location']['path'].split('assets/auto_ml/')[-1]
