@@ -179,10 +179,12 @@ class Volume(WMLResource):
                         json=input_meta
                     )
             if creation_response.status_code == 200:
-                volume_id_details = creation_response.json()
+                volume_id_details = creation_response.json()  # messy details returned for backward compability
                 import copy
                 volume_details = copy.deepcopy(input_meta)
                 volume_details.update(volume_id_details)
+                actual_details = self.get_details(self.get_id(volume_id_details))
+                volume_details.update(actual_details)
                 return volume_details
             else:
                 print(creation_response.status_code, creation_response.text)
@@ -218,6 +220,10 @@ class Volume(WMLResource):
         WMLResource._chk_and_block_create_update_for_python36(self)
         if not self._client.ICP_PLATFORM_SPACES and not self._client.CLOUD_PLATFORM_SPACES:
             raise WMLClientError("Volume APIs are not supported. It is supported only for CP4D 3.5")
+
+        if self._client.ICP_45 and '::' not in name:
+            raise WMLClientError('Invalid name to start volume. Correct volume name format: `<namespace>::<name>`. Retrieve the correct name using `client.volumes.get_name(client.volumes.get_details(volume_id))` command.')
+
         start_url = self._client.service_instance._href_definitions.volume_service_href(name)
         # Start the volume  service
         start_data = {}
